package com.sample;

import org.drools.KnowledgeBase;
import org.drools.builder.KnowledgeBuilder;
import org.drools.builder.KnowledgeBuilderFactory;
import org.drools.builder.ResourceType;
import org.drools.io.ResourceFactory;
import org.drools.logger.KnowledgeRuntimeLogger;
import org.drools.logger.KnowledgeRuntimeLoggerFactory;
import org.drools.runtime.StatefulKnowledgeSession;
import org.drools.runtime.process.WorkflowProcessInstance;

/**
 * This is a sample file to launch a process.
 */
public class ProcessTest {

	public static final void main(String[] args) {
		try {
			// load up the knowledge base
			KnowledgeBase kbase = readKnowledgeBase();
			StatefulKnowledgeSession ksession = kbase.newStatefulKnowledgeSession();
			KnowledgeRuntimeLogger logger = KnowledgeRuntimeLoggerFactory.newFileLogger(ksession, "test");
			Person person = new Person();
			person.setName("John Doe");
			ksession.insert(person);
			// start a new process instance
			WorkflowProcessInstance processInstance = (WorkflowProcessInstance) ksession
					.startProcess("com.sample.bpmn.hello");
			// insert process instance into session
			ksession.insert(processInstance);
			// signal an event
			Event event = new Event();
			event.setData("some data");
			processInstance.signalEvent("Signal", event);
			// fire all rules
			ksession.fireAllRules();
			if (ksession.getProcessInstance(processInstance.getId()) == null) {
				System.out.println("Process completed");
			} else {
				System.out.println("Process NOT completed");
			}
			ksession.dispose();
			logger.close();
		} catch (Throwable t) {
			t.printStackTrace();
		}
	}

	private static KnowledgeBase readKnowledgeBase() throws Exception {
		KnowledgeBuilder kbuilder = KnowledgeBuilderFactory.newKnowledgeBuilder();
		kbuilder.add(ResourceFactory.newClassPathResource("sample.bpmn"), ResourceType.BPMN2);
		kbuilder.add(ResourceFactory.newClassPathResource("sample.drl"), ResourceType.DRL);
		return kbuilder.newKnowledgeBase();
	}

}